@@ -892,6 +892,8 @@ cd_color_rgb_array_is_monotonic (const GPtrArray *array)
 	CdColorRGB *rgb;
 	guint i;
 
+	g_return_val_if_fail (array != NULL, FALSE);
+
 	/* check if monotonic */
 	cd_color_rgb_set (&last_rgb, 0.0, 0.0, 0.0);
 	for (i = 0; i < array->len; i++) {
@@ -947,6 +949,9 @@ cd_color_rgb_array_interpolate (const GPtrArray *array, guint new_length)
 	guint j;
 	guint m;
 
+	g_return_val_if_fail (array != NULL, NULL);
+	g_return_val_if_fail (new_length > 0, NULL);
+
 	/* check if monotonic */
 	ret = cd_color_rgb_array_is_monotonic (array);
 	if (!ret)
@@ -1023,6 +1028,16 @@ cd_color_get_blackbody_rgb (guint temp, CdColorRGB *result)
 	gdouble alpha;
 	gint temp_index;
 
+	/* check lower bound */
+	if (temp < 1000) {
+		temp = 1000;
+	}
+
+	/* check upper bound */
+	if (temp > 10000) {
+		temp = 10000;
+	}
+
 	/* bilinear interpolate the blackbody data */
 	alpha = (temp % 100) / 100.0;
 	temp_index = (temp - 1000) / 100;
