@@ -29,6 +29,9 @@
 #include <glib-object.h>
 #include <colord/cd-color.h>
 #include <colord/cd-profile.h>
+#include <colord/cd-transform.h>
+
+G_BEGIN_DECLS
 
 #ifndef CD_DISABLE_DEPRECATED
 
@@ -85,13 +88,40 @@ G_DEPRECATED_FOR(cd_profile_set_property_sync)
 gboolean	 cd_profile_set_filename_sync		(CdProfile	*profile,
 							 const gchar	*value,
 							 GCancellable	*cancellable,
-							 GError		**error);
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
 G_DEPRECATED_FOR(cd_profile_set_property_sync)
 gboolean	 cd_profile_set_qualifier_sync		(CdProfile	*profile,
 							 const gchar	*value,
 							 GCancellable	*cancellable,
-							 GError		**error);
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
+
+/* add these just in case because of crazy Debian policy */
+G_DEPRECATED_FOR(cd_transform_set_rendering_intent)
+void		 cd_transform_set_intent		(CdTransform	*transform,
+							 CdRenderingIntent rendering_intent);
+G_DEPRECATED_FOR(cd_transform_get_rendering_intent)
+CdRenderingIntent cd_transform_get_intent		(CdTransform	*transform);
+G_DEPRECATED_FOR(cd_transform_set_input_icc)
+void		 cd_transform_set_input			(CdTransform	*transform,
+							 CdIcc		*icc);
+G_DEPRECATED_FOR(cd_transform_get_input_icc)
+CdIcc		*cd_transform_get_input			(CdTransform	*transform);
+
+G_DEPRECATED_FOR(cd_transform_set_output_icc)
+void		 cd_transform_set_output		(CdTransform	*transform,
+							 CdIcc		*icc);
+G_DEPRECATED_FOR(cd_transform_get_output_icc)
+CdIcc		*cd_transform_get_output		(CdTransform	*transform);
+G_DEPRECATED_FOR(cd_transform_set_abstract_icc)
+void		 cd_transform_set_abstract		(CdTransform	*transform,
+							 CdIcc		*icc);
+G_DEPRECATED_FOR(cd_transform_get_abstract_icc)
+CdIcc		*cd_transform_get_abstract		(CdTransform	*transform);
 
 #endif /* CD_DISABLE_DEPRECATED */
 
+G_END_DECLS
+
 #endif /* __CD_DEPRECATED_H__ */
