@@ -31,6 +31,7 @@
 
 #include "config.h"
 
+#include <string.h>
 #include <glib.h>
 #include <gio/gio.h>
 
@@ -80,6 +81,7 @@ cd_profile_connect_sync (CdProfile *profile,
 	CdProfileHelper helper;
 
 	/* create temp object */
+	memset (&helper, 0, sizeof (CdProfileHelper));
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 
@@ -135,6 +137,7 @@ cd_profile_set_property_sync (CdProfile *profile,
 	CdProfileHelper helper;
 
 	/* create temp object */
+	memset (&helper, 0, sizeof (CdProfileHelper));
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 
@@ -186,6 +189,7 @@ cd_profile_install_system_wide_sync (CdProfile *profile,
 	CdProfileHelper helper;
 
 	/* create temp object */
+	memset (&helper, 0, sizeof (CdProfileHelper));
 	helper.loop = g_main_loop_new (NULL, FALSE);
 	helper.error = error;
 
