@@ -73,14 +73,13 @@ cd_quirk_vendor_name (const gchar *vendor)
 		{ "Gigabyte Technology Co., Ltd.", "Gigabyte" },
 		{ "Goldstar Company Ltd", "Goldstar" },
 		{ "Hewlett-Packard", "Hewlett Packard" },
-		{ "Hewlett-Packard", "Hewlett Packard" },
 		{ "Hitachi America Ltd", "Hitachi" },
 		{ "HP", "Hewlett Packard" },
 		{ "HWP", "Hewlett Packard" },
 		{ "IBM France", "IBM" },
 		{ "Lenovo Group Limited", "Lenovo" },
 		{ "LENOVO", "Lenovo" },
-		{ "Liyama North America", "Liyama" },
+		{ "Iiyama North America", "Iiyama" },
 		{ "MARANTZ JAPAN, INC.", "Marantz" },
 		{ "Mitsubishi Electric Corporation", "Mitsubishi" },
 		{ "Nexgen Mediatech Inc.,", "Nexgen Mediatech" },
