@@ -110,7 +110,7 @@ cd_inhibit_get_by_sender (CdInhibit *inhibit,
 	guint i;
 
 	/* find sender */
-	for (i=0; i<priv->array->len; i++) {
+	for (i = 0; i < priv->array->len; i++) {
 		item_tmp = g_ptr_array_index (priv->array, i);
 		if (g_strcmp0 (item_tmp->sender, sender) == 0) {
 			item = item_tmp;
@@ -205,7 +205,7 @@ cd_inhibit_add (CdInhibit *inhibit, const gchar *sender, GError **error)
 	item = g_new0 (CdInhibitItem, 1);
 	item->sender = g_strdup (sender);
 	item->watcher_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
-					     sender,
+					     item->sender,
 					     G_BUS_NAME_WATCHER_FLAGS_NONE,
 					     NULL,
 					     cd_inhibit_name_vanished_cb,
